Re: [PATCH v2 0/8] Support coverage testing with GCC/gcov
- From
Johannes Schindelin <johannes.schindelin@gmx.de>
- Date
- Feb 19, 2009, 13:46 UTC
- Message-ID
- <alpine.DEB.1.00.0902191227260.6223@intel-tinevez-2-302>
- In-Reply-To
- <cover.1235041345.git.trast@student.ethz.ch>
Hi,
On Thu, 19 Feb 2009, Thomas Rast wrote:
Show 22 quoted lines
> Junio C Hamano wrote: > > [Will merge to 'next' soon] > > > > * tr/gcov (Sun Feb 15 23:25:45 2009 +0100) 8 commits > > - Test git-patch-id > > - Test rev-list --parents/--children > > - Test log --decorate > > - Test fsck a bit harder > > - Test log --graph > > - Test diff --dirstat functionality > > - Test that diff can read from stdin > > - Support coverage testing with GCC/gcov > > I noticed two small things that I'd like to fix before this goes > 'next', so here they are: > > * [1/8] Support coverage testing with GCC/gcov > > Changed it so the compilation (but not the testing) uses the same -j > flags as the caller, so that compilation can be done in parallel. > (It's rather minor compared to the slow testing with optimizations > turned off, but still.)
I strongly disagree that it is minor. _Especially_ since the tests are slow, -j makes a huge difference.
And also without making the tests slower, -j makes a dramatic difference here:
$ /usr/bin/time make -j50 test ... 60.41user 213.92system 2:49.34elapsed 162%CPU (0avgtext+0avgdata 0maxresident)k 160inputs+401944outputs (0major+37204627minor)pagefaults 0swaps
$ /usr/bin/time make test ... 88.08user 314.96system 7:28.28elapsed 89%CPU (0avgtext+0avgdata 0maxresident)k 0inputs+401008outputs (0major+37223584minor)pagefaults 0swaps
Ciao, Dscho